{% extends "package/read.html" %}

{%- block subtitle %}{{ _('Validation Report') }}{% endblock -%}

{% block breadcrumb_content_selected %}{% endblock %}

{% block breadcrumb_content %}
  {{ super() }}
  <li class="active"><a href="">{{ _('Entity Diagram') }}</a></li>
{% endblock %}

{% block primary_content %}
<style>
.entity-diagram svg {
  max-width: 90%;
}
</style>
<h1 style="margin-top: 20px;">{{ _('Entity Diagram') }}</h1>
<div class="text-center">
  <div class="entity-diagram">{{ entity_diagram|safe }}</div>
</div>
{% endblock %}

